import { Component, Prop, h, getAssetPath, State } from '@stencil/core';
export class QuickomChatQrCode {
  constructor() {
    this.backgroundColor = '#176DFA';
    this.domain = 'https://quickom-demo.web.app';
    this.isOpen = false;
    this.iframeElement = null;
  }
  toggleButton() {
    this.isOpen = !this.isOpen;
    this.sendMsgToIframe({
      resource: 'chat-box',
      method: this.isOpen ? 'show' : 'hide',
    });
  }
  sendMsgToIframe(msg) {
    this.iframeElement.contentWindow.postMessage(JSON.stringify(msg), this.domain);
  }
  componentWillLoad() {
    this.listenIframeMessage();
  }
  disconnectedCallback() {
    window.removeEventListener('message', this.onMessage);
  }
  getUrl() {
    return `${this.domain}/call/${this.alias}?k=chat-widget`;
  }
  listenIframeMessage() {
    let onMessage = event => {
      if (event.origin !== this.domain) {
        return;
      }
      let data = JSON.parse(event.data);
      switch (data.resource) {
        case 'chat-box':
          this.onChatBoxMessage(data);
          break;
      }
    };
    window.addEventListener('message', onMessage, false);
    this.onMessage = onMessage;
  }
  onChatBoxMessage(data) {
    switch (data.method) {
      case 'show':
        this.isOpen = true;
        break;
      case 'hide':
        this.isOpen = false;
        break;
    }
  }
  render() {
    return (h("div", { class: {
        'sm:absolute': this.isOpen,
        'absolute': !this.isOpen,
      }, style: {
        bottom: 'var(--widget-position-bottom, initial)',
        right: 'var(--widget-position-right, initial)',
        top: 'var(--widget-position-top, initial)',
        left: 'var(--widget-position-left, initial)',
      } },
      h("div", { class: "relative", style: { '--chat-head-bg-color': this.backgroundColor } },
        h("div", { class: {
            'chat-box-container w-screen h-screen sm:w-auto sm:h-auto': true,
            'hidden': !this.isOpen,
          } },
          h("iframe", { ref: el => (this.iframeElement = el), src: this.getUrl(), width: "100%", height: "100%", frameborder: "0" })),
        h("div", { class: { 'text-right': true, 'hidden sm:block mt-2': this.isOpen } },
          h("button", { class: "bubble rounded-full inline-flex items-center text-white justify-center shadow focus:outline-none", onClick: () => this.toggleButton() },
            h("svg-render", { src: getAssetPath(`./assets/speech-bubble.svg`) }))))));
  }
  static get is() { return "quickom-chat-qrcode"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["quickom-chat-qrcode.styl"]
  }; }
  static get styleUrls() { return {
    "$": ["quickom-chat-qrcode.css"]
  }; }
  static get assetsDirs() { return ["assets"]; }
  static get properties() { return {
    "alias": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "alias",
      "reflect": false
    },
    "backgroundColor": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "background-color",
      "reflect": false,
      "defaultValue": "'#176DFA'"
    },
    "domain": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "domain",
      "reflect": false,
      "defaultValue": "'https://quickom-demo.web.app'"
    }
  }; }
  static get states() { return {
    "isOpen": {}
  }; }
}
